@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -16,7 +16,7 @@ from kiva.image import GraphicsContext
 
 
 class TestAggDrawing(DrawingImageTester, unittest.TestCase):
-    def create_graphics_context(self, width, height, pixel_scale):
+    def create_graphics_context(self, width=600, height=600, pixel_scale=2.0):
         return GraphicsContext((width, height), base_pixel_scale=pixel_scale)
 
     def test_save_dpi(self):
